Thiemo Mättig (WMDE) has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/250445

Change subject: Update MediaWiki core version check to 1.26
......................................................................

Update MediaWiki core version check to 1.26

Change-Id: I96f745bbe064a9ed6ce1b93445530266469c1436
---
M client/WikibaseClient.php
M lib/WikibaseLib.php
M repo/Wikibase.php
3 files changed, 8 insertions(+), 6 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/Wikibase 
refs/changes/45/250445/1

diff --git a/client/WikibaseClient.php b/client/WikibaseClient.php
index 88c9f1d..c57f995 100644
--- a/client/WikibaseClient.php
+++ b/client/WikibaseClient.php
@@ -48,8 +48,9 @@
 define( 'WBC_VERSION', '0.5 alpha'
        . ( defined( 'WB_EXPERIMENTAL_FEATURES' ) && WB_EXPERIMENTAL_FEATURES ? 
'/experimental' : '' ) );
 
-if ( version_compare( $GLOBALS['wgVersion'], '1.21c', '<' ) ) { // Needs to be 
1.21c because version_compare() works in confusing ways.
-       die( "<b>Error:</b> Wikibase requires MediaWiki 1.21 alpha or above.\n" 
);
+// Needs to be 1.26c because version_compare() works in confusing ways.
+if ( version_compare( $GLOBALS['wgVersion'], '1.26c', '<' ) ) {
+       die( "<b>Error:</b> Wikibase requires MediaWiki 1.26 or above.\n" );
 }
 
 define( 'WBC_DIR', __DIR__ );
diff --git a/repo/Wikibase.php b/repo/Wikibase.php
index 042d9e8..7041851 100644
--- a/repo/Wikibase.php
+++ b/repo/Wikibase.php
@@ -42,7 +42,8 @@
 define( 'WB_VERSION', '0.5 alpha'
        . ( defined( 'WB_EXPERIMENTAL_FEATURES' ) && WB_EXPERIMENTAL_FEATURES ? 
'/experimental' : '' ) );
 
-if ( version_compare( $GLOBALS['wgVersion'], '1.26c', '<' ) ) { // Needs to be 
1.26c because version_compare() works in confusing ways.
+// Needs to be 1.26c because version_compare() works in confusing ways.
+if ( version_compare( $GLOBALS['wgVersion'], '1.26c', '<' ) ) {
        die( "<b>Error:</b> Wikibase requires MediaWiki 1.26 or above.\n" );
 }
 

diff --git a/lib/WikibaseLib.php b/lib/WikibaseLib.php
index 938e1ab..54299c3 100644
--- a/lib/WikibaseLib.php
+++ b/lib/WikibaseLib.php
@@ -34,9 +34,9 @@
        die( 'Not an entry point.' );
 }
 
-// Needs to be 1.20c because version_compare() works in confusing ways.
-if ( version_compare( $GLOBALS['wgVersion'], '1.20c', '<' ) ) {
-       die( '<b>Error:</b> WikibaseLib requires MediaWiki 1.20 or above.' );
+// Needs to be 1.26c because version_compare() works in confusing ways.
+if ( version_compare( $GLOBALS['wgVersion'], '1.26c', '<' ) ) {
+       die( "<b>Error:</b> Wikibase requires MediaWiki 1.26 or above.\n" );
 }
 
 if ( defined( 'WBL_VERSION' ) ) {
-- 
To view, visit https://gerrit.wikimedia.org/r/250445
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I96f745bbe064a9ed6ce1b93445530266469c1436
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/Wikibase
Gerrit-Branch: master
Gerrit-Owner: Thiemo Mättig (WMDE) <thiemo.maet...@wikimedia.de>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to